@@ -2,8 +2,8 @@
 
 use anchor_lang::prelude::*;
 
-/// Validator for [Accounts] structs.
-pub trait Validate<'info>: Accounts<'info> {
+/// Validates the contents of a variable. Generally used for [Accounts] structs and struct members.
+pub trait Validate<'info> {
     /// Validates the account struct.
     fn validate(&self) -> ProgramResult;
 }
